@@ -6,6 +6,7 @@ use CGI;
 use CGI::Wiki::Plugin::Diff;
 use CGI::Wiki::Plugin::Locator::Grid;
 use OpenGuides::CGI;
+use OpenGuides::Feed;
 use OpenGuides::Template;
 use OpenGuides::Utils;
 use Time::Piece;
@@ -13,7 +14,7 @@ use URI::Escape;
 
 use vars qw( $VERSION );
 
-$VERSION = '0.52';
+$VERSION = '0.53';
 
 =head1 NAME
 
@@ -178,7 +179,7 @@ sub display_node {
     if ($args{format} && $args{format} eq 'raw') {
       print "Content-Type: text/plain\n\n";
       print $raw;
-      exit 0;
+      return 0;
     }
    
     my %metadata_vars = OpenGuides::Template->extract_metadata_vars(
@@ -224,7 +225,7 @@ sub display_node {
             my $output = $self->redirect_to_node($redirect, $id);
             return $output if $return_output;
             print $output;
-            exit 0;
+            return 0;
         }
     }
 
@@ -636,30 +637,30 @@ sub list_all_versions {
     print $output;
 }
 
-=item B<display_rss>
+=item B<display_feed>
 
-  # Last ten non-minor edits to Hammersmith pages.
-  $guide->display_rss(
+  # Last ten non-minor edits to Hammersmith pages in RSS 1.0 format
+  $guide->display_feed(
+                         feed_type          => 'rss',
                          items              => 10,
                          ignore_minor_edits => 1,
                          locale             => "Hammersmith",
                      );
 
-  # All edits bob has made to pub pages in the last week.
-  $guide->display_rss(
-                         days     => 7,
-                         username => "bob",
-                         category => "Pubs",
-                     );
+C<feed_type> is a mandatory parameter. Supported values at present are 
+"rss".
 
 As with other methods, the C<return_output> parameter can be used to
 return the output instead of printing it to STDOUT.
 
 =cut
 
-sub display_rss {
+sub display_feed {
     my ($self, %args) = @_;
 
+    my $feed_type = $args{feed_type};
+    croak "No feed type given" unless $feed_type;
+    
     my $return_output = $args{return_output} ? 1 : 0;
 
     my $items = $args{items} || "";
@@ -672,6 +673,7 @@ sub display_rss {
                        items              => $items,
                        days               => $days,
                        ignore_minor_edits => $ignore_minor_edits,
+                       feed_type          => $feed_type,
                    );
     my %filter;
     $filter{username} = $username if $username;
@@ -681,18 +683,170 @@ sub display_rss {
         $criteria{filter_on_metadata} = \%filter;
     }
 
-    my $rdf_writer = OpenGuides::RDF->new(
-                                             wiki       => $self->wiki,
-                                             config     => $self->config,
-                                             og_version => $VERSION,
-                                         );
-    my $output = "Content-Type: application/rdf+xml\n";
-    $output .= "Last-Modified: " . $rdf_writer->rss_timestamp( %criteria ) . "\n\n";
-    $output .= $rdf_writer->make_recentchanges_rss( %criteria );
+    my $feed = OpenGuides::Feed->new(
+                                        wiki       => $self->wiki,
+                                        config     => $self->config,
+                                        og_version => $VERSION,
+                                    );
+
+    my $output;
+    
+    if ($feed_type eq 'rss') {
+        $output = "Content-Type: application/rdf+xml\n";
+    } else {
+        croak "Unknown feed type given: $feed_type";
+    }
+    
+    $output .= "Last-Modified: " . $feed->feed_timestamp( %criteria ) . "\n\n";
+
+    $output .= $feed->make_feed( %criteria );
+
     return $output if $return_output;
     print $output;
 }
 
+sub display_about {
+    my ($self, %args) = @_;
+
+    my $output;
+
+    if ($args{format} && $args{format} =~ /^rdf$/i) {
+        $output = qq{Content-Type: application/rdf+xml
+
+<?xml version="1.0" encoding="UTF-8"?>
+<rdf:RDF xmlns      = "http://usefulinc.com/ns/doap#"
+         xmlns:rdf  = "http://www.w3.org/1999/02/22-rdf-syntax-ns#"
+         xmlns:foaf = "http://xmlns.com/foaf/0.1/">
+<Project rdf:ID="OpenGuides">
+  <name>OpenGuides</name>
+
+  <created>2003-04-29</created>
+  
+  <shortdesc xml:lang="en">
+    A wiki engine for collaborative description of places with specialised
+    geodata metadata features.
+  </shortdesc>
+
+  <description xml:lang="en">
+    OpenGuides is a collaborative wiki environment, written in Perl, for 
+    building guides and sharing information, as both human-readable text 
+    and RDF. The engine contains a number of geodata-specific metadata 
+    mechanisms such as locale search, node classification and integration 
+    with Google Maps.
+  </description>
+
+  <homepage rdf:resource="http://openguides.org/" />
+  <mailing-list rdf:resource="http://openguides.org/mm/listinfo/openguides-dev/" />
+  <mailing-list rdf:resource="http://urchin.earth.li/mailman/listinfo/openguides-commits/" />
+
+  <maintainer>
+    <foaf:Person rdf:ID="OpenGuidesMaintainer">
+      <foaf:name>Dominic Hargreaves</foaf:name>
+      <foaf:homepage rdf:resource="http://www.larted.org.uk/~dom/" />
+    </foaf:Person>
+  </maintainer>
+
+  <repository>
+    <SVNRepository rdf:ID="OpenGuidesSVN">
+      <location rdf:resource="https://urchin.earth.li/svn/openguides/" />
+      <browse rdf:resource="http://dev.openguides.org/browser" />
+    </SVNRepository>
+  </repository>
+
+  <release>
+    <Version rdf:ID="OpenGuidesVersion">
+      <revision>$VERSION</revision>
+    </Version>
+  </release>
+
+  <download-page rdf:resource="http://search.cpan.org/dist/OpenGuides/" />
+  
+  <!-- Freshmeat category: Internet :: WWW/HTTP :: Dynamic Content -->
+  <category rdf:resource="http://freshmeat.net/browse/92/" />
+  
+  <license rdf:resource="http://www.opensource.org/licenses/gpl-license.php" />
+  <license rdf:resource="http://www.opensource.org/licenses/artistic-license.php" />
+
+</Project>
+
+</rdf:RDF>};
+    }
+    else {
+        my $site_name  = $self->config->{site_name};
+        my $script_name = $self->config->{script_name};
+        $output = qq{Content-Type: text/html; charset=utf-8
+
+<html>
+<head>
+  <title>About $site_name</title>
+<style type="text/css">
+body        { margin: 0px; }
+#content    { padding: 50px; margin: auto; width: 50%; }
+h1          { margin-bottom: 0px; font-style: italic; }
+h2          { margin-top: 0px; }
+#logo       { text-align: center; }
+#logo a img { border: 1px solid #000; }
+#about      { margin: 0em 0em 1em 0em; border-top: 1px solid #ddd; border-bottom: 1px solid #ddd; }
+#meta       { font-size: small; text-align: center;}
+</style>
+<link rel="alternate"
+  type="application/rdf+xml"
+  title="DOAP (Description Of A Project) profile for this site's software" 
+  href="$script_name?action=about;format=rdf" />
+</head>
+<body>
+<div id="content">
+<div id="logo">
+<a href="http://openguides.org/"><img 
+src="http://openguides.org/img/logo.jpg" alt="OpenGuides.org"></a>
+<h1><a href="$script_name">$site_name</a></h1>
+<h2>is powered by <a href="http://openguides.org/">OpenGuides</a> -<br>
+the guides built by you.</h2>
+<h3>version <a href="http://search.cpan.org/~dom/OpenGuides-$VERSION">$VERSION</a></h3>
+</div>
+<div id="about">
+<p>
+<a href="http://www.w3.org/RDF/"><img 
+src="http://openguides.org/img/rdf_icon.png" width="44" height="48"
+style="float: right; margin-left: 10px; border: 0px"></a> OpenGuides is a 
+web-based collaborative <a href="http://wiki.org/wiki.cgi?WhatIsWiki">wiki</a> 
+environment for building guides and sharing information, as both 
+human-readable text and <a href="http://www.w3.org/RDF/"><acronym 
+title="Resource Description Framework">RDF</acronym></a>. The engine contains 
+a number of geodata-specific metadata mechanisms such as locale search, node 
+classification and integration with <a href="http://maps.google.com/">Google 
+Maps</a>.
+</p>
+<p>
+OpenGuides is written in <a href="http://www.perl.org/">Perl</a>, and is
+made available under the same license as Perl itself (dual <a
+href="http://dev.perl.org/licenses/artistic.html" title='The "Artistic Licence"'>Artistic</a> and <a
+href="http://www.opensource.org/licenses/gpl-license.php"><acronym
+title="GNU Public Licence">GPL</acronym></a>). Developer information for the 
+project is available from the <a href="http://dev.openguides.org/">OpenGuides 
+development site</a>.
+</p>
+<p>
+Copyright &copy;2003-2006, <a href="http://openguides.org/">The OpenGuides
+Project</a>. "OpenGuides", "[The] Open Guide To..." and "The guides built by
+you" are trademarks of The OpenGuides Project. Any uses on this site are made 
+with permission.
+</p>
+</div>
+<div id="meta">
+<a href="$script_name?action=about;format=rdf"><acronym
+title="Description Of A Project">DOAP</acronym> RDF version of this 
+information</a>
+</div>
+</div>
+</body>
+</html>};
+    }
+    
+    return $output if $args{return_output};
+    print $output;
+}
+
 =item B<commit_node>
 
   $guide->commit_node(
@@ -950,7 +1104,6 @@ sub get_cookie {
     return $cookie_data{$pref_name};
 }
 
-=back
 
 =head1 BUGS AND CAVEATS
 
